summaryrefslogtreecommitdiffstats
path: root/tests/functional/dht/test_verify_create_hash.py
diff options
context:
space:
mode:
authorSri Vignesh <sselvan@redhat.com>2020-05-11 12:12:59 +0530
committerBala Konda Reddy M <bala12352@gmail.com>2020-05-11 14:39:32 +0000
commitc6ecdf1b82cc6215c058aeaeeeacc70c0f6d82b0 (patch)
treeec293cdd2d409c1f18142b6951bc8978f6a04c38 /tests/functional/dht/test_verify_create_hash.py
parent94dd903a6829041b5791bbc36b309892f4cf3616 (diff)
[TestFix][DHT] Moving test steps from teardown class to teardown
Move cases from teardown class to teardown in dht Change-Id: Id0cf120c6229715521ae19fd4bb00cad553d701f Signed-off-by: Sri Vignesh <sselvan@redhat.com>
Diffstat (limited to 'tests/functional/dht/test_verify_create_hash.py')
-rw-r--r--tests/functional/dht/test_verify_create_hash.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/tests/functional/dht/test_verify_create_hash.py b/tests/functional/dht/test_verify_create_hash.py
index 83f6a7777..2f9fffd7b 100644
--- a/tests/functional/dht/test_verify_create_hash.py
+++ b/tests/functional/dht/test_verify_create_hash.py
@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2018 Red Hat, Inc. <http://www.redhat.com>
+# Copyright (C) 2017-2020 Red Hat, Inc. <http://www.redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
@@ -153,14 +153,14 @@ class TestCreateFile(GlusterBaseClass):
ret, _, _ = g.run(self.clients[0], ("touch %s" % file_one))
self.assertTrue(ret, "Expected file creation to fail")
- @classmethod
- def tearDownClass(cls):
- # Unmount Volume and Cleanup Volume
+ def tearDown(self):
+
+ # Unmount and cleanup original volume
g.log.info("Starting to Unmount Volume and Cleanup Volume")
- ret = cls.unmount_volume_and_cleanup_volume(mounts=cls.mounts)
+ ret = self.unmount_volume_and_cleanup_volume(mounts=self.mounts)
if not ret:
- raise ExecutionError("Failed to Unmount Volume and Cleanup Volume")
- g.log.info("Successful in Unmount Volume and Cleanup Volume")
+ raise ExecutionError("Failed to umount the vol & cleanup Volume")
+ g.log.info("Successful in umounting the volume and Cleanup")
- # Calling GlusterBaseClass tearDownClass
- cls.get_super_method(cls, 'tearDownClass')()
+ # Calling GlusterBaseClass tearDown
+ self.get_super_method(self, 'tearDown')()